# CPAGYM: Certified Public Accountant Reinforcement Learning Toolkit

[![](https://raw.githubusercontent.com/accounting-intelligent-ai/cpagym/main/cpagym.png)](https://cpanlp.com)

## Install & Import 安装和导入
For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).
```python
pip install cpagym
import cpagym as cg
```


Check out: https://cpanlp.com